loader

package
v1.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 30, 2019 License: BSD-3-Clause Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Loader

type Loader interface {
	LoadFile(fileName string) (io.ReadCloser, error)
}

Loader is the interface for loading files from any datasource you would like to specify; make sure that you implement this interface when developing support for reading fingerprint files from your own desired sources!

type S3

type S3 struct {
	// contains filtered or unexported fields
}

S3 implements interface Loader, so it can be used in an mitmengine.Config struct when getting a mitmengine.Processor.

func NewS3Instance

func NewS3Instance() (*S3, error)

NewS3Instance creates S3 struct using configs loaded from environment variables

func (*S3) LoadFile

func (s3Instance *S3) LoadFile(fileName string) (io.ReadCloser, error)

LoadFile implements the LoadFile function specified in Loader interface, as defined in loader.go

Jump to